==> refcodes-cli-2.1.4-sources.jar: org/refcodes/cli/ParseArgsException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

/**
 * Thrown in case the provided command line arguments do not respect the
 * required syntax or cannot be converted to the required type.
 */
public class ParseArgsException extends ArgsMismatchException {

	// /////////////////////////////////////////////////////////////////////////
	// STATIC:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, String aMessage, String aErrorCode ) {
		super( aArgs, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aArgs, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param message the message
	 * @param cause the cause
	 */
	public ParseArgsException( String[] aArgs, String message, Throwable cause ) {
		super( aArgs, message, cause );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param message the message
	 */
	public ParseArgsException( String[] aArgs, String message ) {
		super( aArgs, message );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, Throwable aCause, String aErrorCode ) {
		super( aArgs, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param cause the cause
	 */
	public ParseArgsException( String[] aArgs, Throwable cause ) {
		super( aArgs, cause );
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////
}

==> refcodes-cli-2.2.2-sources.jar: org/refcodes/cli/ParseArgsException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// /////////////////////////////////////////////////////////////////////////////
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// -----------------------------------------------------------------------------
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// -----------------------------------------------------------------------------
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// -----------------------------------------------------------------------------
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.cli;

/**
 * Thrown in case the provided command line arguments do not respect the
 * required semantics or cannot be converted to the required type.
 */
public class ParseArgsException extends ArgsSyntaxException {

	// /////////////////////////////////////////////////////////////////////////
	// STATICS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTANTS:
	// /////////////////////////////////////////////////////////////////////////

	private static final long serialVersionUID = 1L;

	// /////////////////////////////////////////////////////////////////////////
	// VARIABLES:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// CONSTRUCTORS:
	// /////////////////////////////////////////////////////////////////////////

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, String aMessage, String aErrorCode ) {
		super( aArgs, aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, String aMessage, Throwable aCause, String aErrorCode ) {
		super( aArgs, aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param message the message
	 * @param cause the cause
	 */
	public ParseArgsException( String[] aArgs, String message, Throwable cause ) {
		super( aArgs, message, cause );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param message the message
	 */
	public ParseArgsException( String[] aArgs, String message ) {
		super( aArgs, message );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public ParseArgsException( String[] aArgs, Throwable aCause, String aErrorCode ) {
		super( aArgs, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new parses the args exception.
	 *
	 * @param aArgs the args
	 * @param cause the cause
	 */
	public ParseArgsException( String[] aArgs, Throwable cause ) {
		super( aArgs, cause );
	}

	// /////////////////////////////////////////////////////////////////////////
	// METHODS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HOOKS:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// HELPER:
	// /////////////////////////////////////////////////////////////////////////

	// /////////////////////////////////////////////////////////////////////////
	// INNER CLASSES:
	// /////////////////////////////////////////////////////////////////////////
}
